Date: 01 4, 2002 12:57:04 PM

# movecleft

## Purpose

Move a concept childConcept before previous sibling. (Moves the concept to the 'left' or 'higher' in the pecking order.)

## Syntax

None = movecleft(childConcept)

childConcept - type: con

## Returns

Nothing.

## Remarks

If you try to move a concept beyond the first concept, a message is written to the output log.

## Example

@CODE
"output.txt" << "move\n";
G("alpha") = makeconcept(findroot(),"first");
G("beta") = makeconcept(findroot(),"second");
G("gamma") = makeconcept(findroot(),"third");
movecleft(G("gamma"));
movecright(G("alpha"));

This prints the following to output.txt:

move

After this code is executed, the KB Editor looks like this:

## See Also

movecright, Knowledge Base Functions